RequestDestination

Enum RequestDestination 

pub enum RequestDestination {
Show 22 variants Audio, AudioWorklet, Document, Embed, Font, Frame, IFrame, Image, Manifest, None, Object, PaintWorklet, Report, Script, ServiceWorker, SharedWorker, Style, Track, Video, WebIdentity, Worker, Xslt,
}
The Request Destination specifies what the destination of this fetch is.

Variants



Audio

HTML <audio>



AudioWorklet

audioScript.addModule()



Document

A website is loaded, and this is e.g. the HTML document.



Embed

HTML <embed>



Font

CSS @font-face



Frame

HTML <frame>



IFrame

HTML <iframe>



Image

"" initiator

  • <img src>
  • /favicon resource
  • SVG <image>
  • CSS background-image
  • CSS cursor
  • CSS list-style-image

imageset initiator

  • HTML <img srcset>
  • HTML <picture>


Manifest

<link rel=manifest>



None

The empty string "". This can come from one of:

"" initiator

  1. navigator.sendBeacon()
  2. EventSource
  3. <a ping="">
  4. <area ping="">
  5. fetch()
  6. XMLHttpRequest
  7. WebSocket
  8. Cache API

download initiator

  • HTML download attribute
  • Save Link As… in the browser UI

prefetch initiator

  • HTML <link rel=prefetch>

prerender initiator

  • HTML <link rel=prerender>


Object

HTML <object>



PaintWorklet

CSS.paintWorklet.addModule()



Report

CSP, NEL reports.



Script

  • <script>
  • importScripts()


ServiceWorker

navigator.serviceWorker.register()



SharedWorker

SharedWorker



Style

  • HTML <link rel=stylesheet>
  • CSS @import


Track

HTML <track>



Video

HTML <video>



WebIdentity

Federated Credential Management requests



Worker

Worker



Xslt

<?xml-stylesheet>

Implementations

Source

impl RequestDestination

pub fn as_str(&self) -> &str

Get the normative string representation, as per Fetch.

pub fn is_script_like(&self) -> bool

Specifies if the request is initiated by a script load, or activated by some features in JavaScript.

Specification Warning

Algorithms that use script-like should also consider “xslt” as that too can cause script execution. It is not included in the list as it is not always relevant and might require different behavior.

Specifications