pub enum RequestReferrer {
NoReferrer,
Client,
Url(Url),
}Expand description
Specifies the type of referrer a request should be associated with.
Most requests have a specific origin, most likely a script or document, that
initiated/linked the resource pointed to by this request. For example, a
HTML document might have images (<img>), and those images should be
requested from a server. To follow web security practices, a HTTP
Referer header should be associated with the request.
Variants
NoReferrer
No referrer was found or associated with this request (for example, top-level documents), or the client/server has explicitly disabled referrer by policy.
Client
The default value, which specifies that Fetch should determine the referrer using the algorithm.
Url(Url)
The request was referred to by