Fetch

Struct Fetch 

pub struct Fetch { /* private fields */ }
This struct contains the Fetch object, which can be used to fetch resources using the internet. This object can be safely shared across components and threads.

Implementations

Source

impl Fetch

pub fn create_instantaneous_response( &self, request: Arc<Request>, response: FetchResponse, ) -> FetchPromise

Create a new FetchPromise that resolves instantaneously.

pub fn new() -> Self

Create a new Fetch object.

pub fn with_user_agent<S>(user_agent: S) -> Self
where S: Into<Arc<str>>,

Create a new Fetch object.

pub fn fetch(&self, request: Request) -> FetchPromise

Load the resource associated with the request asynchronously.

pub fn fetch_document( &self, url: Url, referrer: RequestReferrer, ) -> FetchPromise

Fetch a document, given the url and optionally a referrer.