pub struct Request { /* private fields */ }Expand description
The Request class.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn new(
url: Url,
initiator: RequestInitiator,
destination: RequestDestination,
mode: RequestMode,
referrer: RequestReferrer,
) -> Self
pub fn new( url: Url, initiator: RequestInitiator, destination: RequestDestination, mode: RequestMode, referrer: RequestReferrer, ) -> Self
Create a new [Request][https://fetch.spec.whatwg.org/#request-class].
Sourcepub fn get_document(url: Url, referrer: RequestReferrer) -> Self
pub fn get_document(url: Url, referrer: RequestReferrer) -> Self
A helper to create a Request, specifically for Document retrieval with navigation (i.e. top-level browser contexts).
Sourcepub fn accept_header_value(&self) -> &str
pub fn accept_header_value(&self) -> &str
Compute or get the value of the Accept header, which specifies
what type of content is acceptable for us to handle.