Re-exports
Structs
- Fetch
- This struct contains the Fetch object, which can be used to fetch resources using the internet. This object can be safely shared across components and threads.
- Fetch
Promise - An async-library agnostic awaitable.
- Request
- The Request class.
- Response
- Represents the HTTP response to an request.
- Status
Code - A convenient wrapper for the HTTP Status Code.
- Url
- A parsed URL record.
Enums
- Error
- An error that can occur within the library or network stack.
- Internal
Error - An error that occurred within the retina-fetch crate.
- Network
Error - A network error occurred whilst processing the request/response.
- Request
Destination - The Request Destination specifies what the destination of this
fetchis. - Request
Initiator - The Request Initiator specifies which component started the request.
- Request
Mode - The request has an associated mode, which is an important concept in Cross Origin Resource Sharing.
- Request
Referrer - Specifies the type of referrer a request should be associated with.
Most requests have a specific origin, most likely a script or document, that
initiated/linked the resource pointed to by this request. For example, a
HTML document might have images (
<img>), and those images should be requested from a server. To follow web security practices, a HTTPRefererheader should be associated with the request. - Status
Code Class - The class of the status code determine the result of the request and the semantics of the response.
Functions
- parse_
page_ url - Parse a page URL. This function is laxer than the regular
Url::parse()parser, since the user can omit certain elements (like the scheme).
Type Aliases
- Fetch
Response - This type specifies what the
Fetch::fetch()API returns.